@@ -1,5 +1,5 @@
 package POE::Filter::MessagePack;
-
+$POE::Filter::MessagePack::VERSION = '1.170412';
 # ABSTRACT: A dead-simple POE::Filter for MessagePack
 use strict;
 use warnings;
@@ -57,6 +57,18 @@ sub put {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+POE::Filter::MessagePack - A dead-simple POE::Filter for MessagePack
+
+=head1 VERSION
+
+version 1.170412
+
 =head1 SYNOPSIS
 
     use POE::Filter::MessagePack;
@@ -78,4 +90,15 @@ __END__
     This is a POE filter for MessagePacked data. Do not stack this with
     POE::Filter::Line, as MessagePack data is not line-oriented.
 
+=head1 AUTHOR
+
+Nick Shipp <nick@shipp.ninja>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Nick Shipp.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
